@@ -4,7 +4,7 @@ use 5.008_005;
 use strict;
 use warnings FATAL => 'all';
 
-our $VERSION = '0.09'; # Set automatically by milla
+our $VERSION = '0.10'; # Set automatically by milla
 
 my $based = {
 	'default.base' => 'Rest::HtmlVis::Base',
@@ -20,10 +20,12 @@ sub new {
 
 	### Set uri path
 	$self->{baseurl} = "/static";
-	$self->{baseurl} = delete $params->{'default.baseurl'} if exists $params->{'default.baseurl'};
+	# Don't delete key, because of original hash
+	$self->{baseurl} = $params->{'default.baseurl'} if exists $params->{'default.baseurl'};
 
 	### Add htmlvis
 	foreach my $key (sort keys %$params){
+		next if $key eq 'default.baseurl';
 		$self->loadVisObject($key, $params->{$key});
 	}
 
